AdmostInterstitial class

Inheritance

Constructors

AdmostInterstitial({required String zoneId, void listener(AdmostAdEvent, Map<String, dynamic>)?})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
isLoaded → Future<bool?>
no setter
listener → void Function(AdmostAdEvent, Map<String, dynamic>)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoneId → String
final

Methods

dispose() → void
handleEvent(MethodCall call) → Future
inherited
load() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
show([String? tag]) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited