AdMostRemoteConfig class

Constructors

AdMostRemoteConfig()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getBoolean({required String key, required bool defaultValue}) → Future<bool?>
getNum({required String key, required num defaultValue}) → Future<num?>
getString({required String key, required String defaultValue}) → Future<String?>